#pragma once
/* This is a GENERATED file */
#ifndef __GWYDDION_AUTHORS_H__
#define __GWYDDION_AUTHORS_H__
static const gchar developers[] =
  "David Nečas (Yeti)\n"
  "Petr Klapetek\n"
  "Christopher Anderson\n"
  "Martin Šiler\n"
  "Jindřich Bílek\n"
  "Nenad Ocelic\n"
  "Rok Zitko\n"
  "Lukáš Chvátal\n"
  "Sven Neumann\n"
  "Jan Hořák\n"
  "Александр Ковалев\n"
  "Owain Davies\n"
  "Rolf Würdemann\n"
  "Dirk Kähler\n"
  "Miroslav Valtr\n"
  "Martin Hasoň\n"
  "Philipp Rahe\n"
  "Matthew Caldwell\n"
  "Андрей Груздев\n"
  "Даниил Браташов\n"
  "François Bianco\n"
  "Luke Somers\n"
  "Vojtěch Salajka\n"
  "Anna Campbellova\n"
  "Lennart Fricke\n"
  "Jozef Veselý\n"
  "Gianfranco Gallizia\n"
  "Sameer Grover\n"
  "Niv Levy\n"
  "Vinicius Barboza\n"
  "Jeffrey J. Schwartz\n"
  "Christian Bühler\n"
  "Евгений Рябов\n"
  "Petr Grolich\n"
  "Samo Ziberna\n"
  "Antony Kikaxa\n"
  "Felix Kling\n"
  "Robb Puttock\n"
  "Radek Šlesinger\n"
  "Thomas Wagner\n"
  "Vojtěch Klapetek\n"
  "Moutaz Haq\n"
;
static const gchar translators[] =
  "David Nečas (Yeti)\n"
  "Petr Klapetek\n"
  "Livia Della Seta\n"
  "Philipp Leufke\n"
  "Johannes Römer\n"
  "François Riguet\n"
  "Даниил Браташов\n"
  "Andrés Muñiz Piniella\n"
  "Fellype do Nascimento\n"
  "Jeong Jiseong\n"
  "Julian Hofer\n"
  "Sabrina Meindlhumer\n"
  "Ikuo Obataya\n"
;
#endif
